==> miappio-sdk-2.0.34.tgz: package/README.md <==

[![Build Status](https://travis-ci.org/miappio/miappio-sdk.svg?branch=master)](https://travis-ci.org/miappio/miappio-sdk) [![NPM version](https://badge.fury.io/js/miappio-sdk.svg)](https://www.npmjs.com/package/miappio-sdk) [![Bower version](https://badge.fury.io/bo/miappio-sdk.svg)](https://libraries.io/bower/miappio-sdk)

> [Install](https://github.com/miappio/miappio-sdk#install) | [APIs](https://miappio.github.io/miappio-sdk) | [Support](https://github.com/miappio/miappio-sdk#develop) | [Thanks!](https://github.com/miappio/miappio-sdk#thanks)


# 1) You're an app builder
Thank you for building great app. 
Miapp.io will support you to manager auth, session storage.

### Easiest way

From scratch, with *yeoman* like described in this blog post : **[TODO]** 
```bash
yo miappio
``` 

### Normal way

Install with NPM :
```bash
npm install miappio-sdk --save
```
Or Bower :
```bash
bower install miappio-sdk
```

Then look at APIs and integration patterns described in [https://miappio.github.io/miappio-sdk/](https://miappio.github.io/miappio-sdk/miapp.html)
- with [Angular](https://miappio.github.io/miappio-sdk/miapp.angularService.html)
- with [Angular.js](https://miappio.github.io/miappio-sdk/miapp.angularService.html)
- with pure js

or in brief (if your familiar with promise) :
```js
// init your app
miappService.init('yourMiappId')
.then(function() {
    // login (auto register) your user
    return miappService.login('login', 'password');
})
.then(function() {
    // synchronise your session data
    return miappService.sync();
})
.then(function() {
    // put your data into session, 
    // it will be available everywhere but also offline
    return miappService.put({data : 'my session'});
})
//... sync, get data and so on
.catch(function(err) {
    alert(err);
    miappService.logout();
});

```


# 2) You're a miapp.io dev
Thank you for your support !

Miapp.io is an Open Source project - we need you to provide great tools to great apps.

## Develop

Fork the project
```bash
git clone https://github.com/miappio/miappio-sdk.git
cd miappio-sdk
npm install
```
and pull request ...

### Testing

With npm :
```bash
$ npm test
```

With a swagger UI :  
https://app.swaggerhub.com/api/mlefree/miapp-io_rest_api/


# Thanks

[@miapp.io](https://miapp.io) @mat_cloud

==> miappio-sdk-2.0.45.tgz: package/README.md <==

[![Build Status](https://travis-ci.org/miappio/miappio-sdk.svg?branch=master)](https://travis-ci.org/miappio/miappio-sdk) [![NPM version](https://badge.fury.io/js/miappio-sdk.svg)](https://www.npmjs.com/package/miappio-sdk) [![Bower version](https://badge.fury.io/bo/miappio-sdk.svg)](https://libraries.io/bower/miappio-sdk)

> [Install](https://github.com/miappio/miappio-sdk#install) | [APIs](https://miappio.github.io/miappio-sdk) | [Support](https://github.com/miappio/miappio-sdk#develop) | [Thanks!](https://github.com/miappio/miappio-sdk#thanks)


# 1) You're an app builder
Thank you for building great app. 
Miapp.io will support you to manager auth, session storage.

### Easiest way

From scratch, with *yeoman* like described in this blog post : **[TODO]** 
```bash
yo miappio
``` 

### Normal way

Install with NPM :
```bash
npm install miappio-sdk --save
```
Or Bower :
```bash
bower install miappio-sdk
```

Then look at APIs and integration patterns described in [https://miappio.github.io/miappio-sdk/](https://miappio.github.io/miappio-sdk/interfaces/_sdk_interfaces_.moduleserviceinterface.html)
- with [Angular](https://miappio.github.io/miappio-sdk/miapp.angularService.html)
- with [Angular.js](https://miappio.github.io/miappio-sdk/miapp.angularService.html)
- with pure js

or in brief (if your familiar with promise) :
```js
// init your app
miappService.init('yourMiappId')
.then(function() {
    // login (auto register) your user
    return miappService.login('login', 'password');
})
.then(function() {
    // synchronise your session data
    return miappService.sync();
})
.then(function() {
    // put your data into session, 
    // it will be available everywhere but also offline
    return miappService.put({data : 'my session'});
})
//... sync, get data and so on
.catch(function(err) {
    alert(err);
    miappService.logout();
});

```


# 2) You're a miapp.io dev
Thank you for your support !

Miapp.io is an Open Source project - we need you to provide great tools to great apps.

## Develop

Fork the project
```bash
git clone https://github.com/miappio/miappio-sdk.git
cd miappio-sdk
npm install
```
and pull request ...

### Testing

With npm :
```bash
$ npm test
```

With a swagger UI :  
https://app.swaggerhub.com/api/mlefree/miapp-io_rest_api/


# Thanks

[@miapp.io](https://miapp.io) @mat_cloud
